==> qtwebengine-opensource-src_5.7.1+dfsg.orig.tar.xz: qtwebengine-opensource-src-5.7.1/src/3rdparty/chromium/content/common/service_worker/service_worker_client_info.h <==
// Copyright 2015 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CONTENT_COMMON_SERVICE_WORKER_SERVICE_WORKER_CLIENT_INFO_H_
#define CONTENT_COMMON_SERVICE_WORKER_SERVICE_WORKER_CLIENT_INFO_H_

#include "base/time/time.h"
#include "content/public/common/request_context_frame_type.h"
#include "third_party/WebKit/public/platform/WebPageVisibilityState.h"
#include "third_party/WebKit/public/platform/modules/serviceworker/WebServiceWorkerClientType.h"
#include "url/gurl.h"

namespace content {

// This class holds the information related to a service worker window client.
// It is the content/ equivalent of Blink's WebServiceWorkerClientInfo.
// An instance can be created empty or can be filed with the expected
// properties. Except for the client_uuid, it is preferred to use the
// constructor to fill the properties.
struct ServiceWorkerClientInfo {
  ServiceWorkerClientInfo();
  ServiceWorkerClientInfo(blink::WebPageVisibilityState page_visibility_state,
                          bool is_focused,
                          const GURL& url,
                          RequestContextFrameType frame_type,
                          base::TimeTicks last_focus_time,
                          blink::WebServiceWorkerClientType client_type);

  // Returns whether the instance is empty.
  bool IsEmpty() const;

  // Returns whether the instance is valid. A valid instance is not empty and
  // has a valid client_uuid.
  bool IsValid() const;

  std::string client_uuid;
  blink::WebPageVisibilityState page_visibility_state;
  bool is_focused;
  GURL url;
  RequestContextFrameType frame_type;
  blink::WebServiceWorkerClientType client_type;
  base::TimeTicks last_focus_time;
};

}  // namespace content

#endif  // CONTENT_COMMON_SERVICE_WORKER_SERVICE_WORKER_CLIENT_INFO_H_

==> qtwebengine-opensource-src-5.9.9.tar.xz: qtwebengine-opensource-src-5.9.9/src/3rdparty/chromium/content/common/service_worker/service_worker_client_info.h <==
// Copyright 2015 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CONTENT_COMMON_SERVICE_WORKER_SERVICE_WORKER_CLIENT_INFO_H_
#define CONTENT_COMMON_SERVICE_WORKER_SERVICE_WORKER_CLIENT_INFO_H_

#include "base/time/time.h"
#include "content/public/common/request_context_frame_type.h"
#include "third_party/WebKit/public/platform/WebPageVisibilityState.h"
#include "third_party/WebKit/public/platform/modules/serviceworker/WebServiceWorkerClientType.h"
#include "url/gurl.h"

namespace content {

// This class holds the information related to a service worker window client.
// It is the content/ equivalent of Blink's WebServiceWorkerClientInfo.
// An instance can be created empty or can be filed with the expected
// properties. Except for the client_uuid, it is preferred to use the
// constructor to fill the properties.
struct ServiceWorkerClientInfo {
  ServiceWorkerClientInfo();
  ServiceWorkerClientInfo(const std::string& client_uuid,
                          blink::WebPageVisibilityState page_visibility_state,
                          bool is_focused,
                          const GURL& url,
                          RequestContextFrameType frame_type,
                          base::TimeTicks last_focus_time,
                          blink::WebServiceWorkerClientType client_type);
  ServiceWorkerClientInfo(const ServiceWorkerClientInfo& other);

  // Returns whether the instance is empty.
  bool IsEmpty() const;

  // Returns whether the instance is valid. A valid instance is not empty and
  // has a valid client_uuid.
  bool IsValid() const;

  std::string client_uuid;
  blink::WebPageVisibilityState page_visibility_state;
  bool is_focused;
  GURL url;
  RequestContextFrameType frame_type;
  base::TimeTicks last_focus_time;
  blink::WebServiceWorkerClientType client_type;
};

}  // namespace content

#endif  // CONTENT_COMMON_SERVICE_WORKER_SERVICE_WORKER_CLIENT_INFO_H_
